## Security Policy
We strongly recommend using the latest version of Admyral to receive all security updates.

For more information, please refer to the [Security](https://docs.admyral.dev/security) page in the documentation or contact [chris@admyral.dev](mailto:chris@admyral.dev).